#include "TMVA/Tools.h"
#include "TMVA/Reader.h"
#include "TMVA/MethodCuts.h"

using namespace TMVA;

float BDT() {

  Float_t Z_eta;
  Float_t mT_ZZ;
  Float_t dLepR;
  Float_t dMetZPhi;
  Float_t met_signif;
  Float_t frac_pT;
  Float_t MetOHT;
  Float_t met_tst;
  Float_t mT_Hinv;
  Float_t M2Lep;
  Float_t sumpT_scalar;
  Float_t dLepEta;
  Float_t dLepPhi;
  Float_t lepplus_phi;
  Float_t lepminus_eta;
  Float_t lepplus_eta;
  Float_t lepminus_phi;
  Int_t n_bjets,event_3CR,event_type;


  TMVA::Reader *tmvaReader = new TMVA::Reader("!Color:!Silent");

  // active variables
  tmvaReader->AddVariable("Z_eta", &Z_eta);
  tmvaReader->AddVariable("mT_ZZ", &mT_ZZ);
  tmvaReader->AddVariable("dLepR", &dLepR);
  tmvaReader->AddVariable("dMetZPhi", &dMetZPhi);
  tmvaReader->AddVariable("met_signif", &met_signif);
  tmvaReader->AddVariable("frac_pT", &frac_pT);
  tmvaReader->AddVariable("MetOHT", &MetOHT);
  tmvaReader->AddVariable("met_tst", &met_tst);
  tmvaReader->AddVariable("mT_Hinv", &mT_Hinv);
  tmvaReader->AddVariable("M2Lep", &M2Lep);
  tmvaReader->AddVariable("sumpT_scalar", &sumpT_scalar);
  tmvaReader->AddVariable("fabs(lepplus_eta-lepminus_eta)", &dLepEta);
  tmvaReader->AddVariable("fabs(lepplus_phi-lepminus_phi)", &dLepPhi);
  // spectator variables
  tmvaReader->AddSpectator("event_3CR", &event_3CR);
  tmvaReader->AddSpectator("n_bjets", &n_bjets);
  tmvaReader->AddSpectator("event_type", &event_type);

  TString bdtPath = "./weights/TMVAClassification_BDTG.weights.xml";
  tmvaReader->BookMVA("BDTG method", bdtPath);
/*
  TString filename = "test.root";
  TFile *input(0);
  input = TFile::Open(filename); 
  TTree* theTree = (TTree*)input->Get("tree_PFLOW");

theTree->SetBranchAddress( "dLepR", &dLepR );
theTree->SetBranchAddress( "dMetZPhi", &dMetZPhi );
theTree->SetBranchAddress( "frac_pT",&frac_pT );
theTree->SetBranchAddress( "MetOHT", &MetOHT );
theTree->SetBranchAddress( "event_3CR", &event_3CR );
theTree->SetBranchAddress( "n_bjets", &n_bjets );
theTree->SetBranchAddress( "met_tst", &met_tst );
theTree->SetBranchAddress( "met_signif", &met_signif );
theTree->SetBranchAddress( "event_type", &event_type );
theTree->SetBranchAddress( "mT_Hinv", &mT_Hinv );
theTree->SetBranchAddress( "Z_eta", &Z_eta);
theTree->SetBranchAddress( "mT_ZZ", &mT_ZZ);
theTree->SetBranchAddress( "M2Lep", &M2Lep);
theTree->SetBranchAddress( "sumpT_scalar", &sumpT_scalar);
theTree->SetBranchAddress( "lepplus_eta", &lepplus_eta);
theTree->SetBranchAddress( "lepplus_phi", &lepplus_phi);
theTree->SetBranchAddress( "lepminus_eta", &lepminus_eta);
theTree->SetBranchAddress( "lepminus_phi", &lepminus_phi);

      theTree->GetEntry(0);

 cout << "Z_eta=" <<  Z_eta<< endl;
 cout <<"mT_ZZ=" <<mT_ZZ<< endl;
 cout <<"dLepR=" <<dLepR<< endl;
 cout <<"dMetZPhi=" <<dMetZPhi<< endl;
 cout <<"met_signif=" << met_signif<< endl;
 cout <<"frac_pT=" << frac_pT<< endl;
 cout <<"MetOHT=" << MetOHT<< endl;
 cout <<"met_tst" << met_tst<< endl;
 cout <<"mT_Hinv" << mT_Hinv<< endl;
 cout <<"M2Lep" << M2Lep<< endl;
 cout <<"sumpT_scalar=" <<sumpT_scalar<< endl;
 cout <<"dLepEta=" << fabs(lepplus_eta-lepminus_eta)<< endl;
 cout <<"dLepPhi=" <<fabs(lepplus_phi-lepminus_phi)<< endl;
 cout <<"event_3CR=" << event_3CR<< endl;
 cout <<"n_bjets=" << n_bjets<< endl;
 cout <<"event_type=" << event_type<< endl;

*/
Z_eta=0.222565;
mT_ZZ=280.711;
dLepR=1.00976;
dMetZPhi=2.98648;
met_signif=4.5451;
frac_pT=0.0866339;
MetOHT=0.174369;
met_tst=63.6785;
mT_Hinv=203.366;
M2Lep=86.2474;
sumpT_scalar=365.194;
dLepEta=0.37677;
dLepPhi=0.936832;
event_3CR=0;
n_bjets=0;
event_type=1;

  Float_t bdt = tmvaReader->EvaluateMVA("BDTG method");
  cout << "BDT: " << bdt << std::endl;

return 0;
}
